#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: optparse-simple
version: 0.0.3
id: optparse-simple-0.0.3-fc29ed695aba9c6283393ad528c4c040
key: optpa_C4tyRiouNdxFrFA84z4lGn
license: BSD3
copyright: 2015 FP Complete
maintainer: chrisdone@fpcomplete.com
synopsis: Simple interface to optparse-applicative
description:
    Simple interface to optparse-applicative
category: Options
author: FP Complete
exposed: True
exposed-modules:
    Options.Applicative.Simple
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/optparse-simple-0.0.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/optparse-simple-0.0.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/optparse-simple-0.0.3
hs-libraries: HSoptparse-simple-0.0.3-C4tyRiouNdxFrFA84z4lGn
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    either-4.4.1-41aae3c9f6fd5e3bc6375970f322f3dd
    gitrev-1.2.0-e94a60465b66be18f7d5d663af7880a5
    optparse-applicative-0.12.1.0-efdb53d7ee5eb339e181252750b5ba21
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-optparse-simple/html/optparse-simple.haddock
haddock-html: /usr/share/doc/haskell-optparse-simple/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
